.. redirect-from:: /users/prev_whats_new/github_stats_3.6.1

.. _github-stats-3-6-1:

GitHub statistics for 3.6.1 (Oct 08, 2022)
==========================================

GitHub statistics for 2022/09/16 (tag: v3.6.0) - 2022/10/08

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 22 issues and merged 80 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/73?closed=1>`__

The following 19 authors contributed 129 commits.

* Antony Lee
* baharev
* David Stansby
* dependabot[bot]
* Eli Rykoff
* Elliott Sales de Andrade
* erykoff
* Greg Lucas
* hannah
* Ian Hunt-Isaak
* Jody Klymak
* melissawm
* Oscar Gustafsson
* Ruth Comer
* slackline
* Steffen Rehberg
* Thomas A Caswell
* Tim Hoffmann
* مهدي شينون (Mehdi Chinoune)

GitHub issues and pull requests:

Pull Requests (80):

* :ghpull:`24124`: Backport PR #24111 on branch v3.6.x (FIX: add missing method to ColormapRegistry)
* :ghpull:`24111`: FIX: add missing method to ColormapRegistry
* :ghpull:`24117`: Backport PR #24113 on branch v3.6.x (Add exception class to pytest.warns calls)
* :ghpull:`24116`: Backport PR #24115 on branch v3.6.x (Fix mask lookup in fill_between for NumPy 1.24+)
* :ghpull:`24113`: Add exception class to pytest.warns calls
* :ghpull:`24115`: Fix mask lookup in fill_between for NumPy 1.24+
* :ghpull:`24112`: Backport PR #24109 on branch v3.6.x (DOC: add API change note for colorbar deprecation)
* :ghpull:`24109`: DOC: add API change note for colorbar deprecation
* :ghpull:`24107`: Backport PR #24088 on branch v3.6.x (MNT: make orphaned colorbar deprecate versus raise)
* :ghpull:`24088`: MNT: make orphaned colorbar deprecate versus raise
* :ghpull:`24103`: Backport PR #23684 on branch v3.6.x (Fix rectangle and hatches for colorbar)
* :ghpull:`23684`: Fix rectangle and hatches for colorbar
* :ghpull:`24087`: Backport PR #24084 on branch v3.6.x (Revert argument checking for label_mode)
* :ghpull:`24084`: Revert argument checking for label_mode
* :ghpull:`24078`: Backport PR #24047 on branch v3.6.x (Revert #22360: Let TeX handle multiline strings itself)
* :ghpull:`24047`: Revert #22360: Let TeX handle multiline strings itself
* :ghpull:`24077`: Backport PR #24054 on branch v3.6.x ( DOC: Move OO-examples from pyplot section)
* :ghpull:`24054`:  DOC: Move OO-examples from pyplot section
* :ghpull:`24072`: Backport PR #24069 on branch v3.6.x (Clarification of marker size in scatter)
* :ghpull:`24073`: Backport PR #24070 on branch v3.6.x (DOC: colorbar may steal from array of axes)
* :ghpull:`24070`: DOC: colorbar may steal from array of axes
* :ghpull:`24069`: Clarification of marker size in scatter
* :ghpull:`24059`: Backport PR #23638 on branch v3.6.x (FIX: correctly handle generic font families in svg text-as-text mode)
* :ghpull:`23638`: FIX: correctly handle generic font families in svg text-as-text mode
* :ghpull:`24048`: Backport PR #24045 on branch v3.6.x (Fix _FigureManagerGTK.resize on GTK4)
* :ghpull:`24055`: Backport PR #24046 on branch v3.6.x (Ignore 'CFMessagePort: bootstrap_register' messages)
* :ghpull:`24046`: Ignore 'CFMessagePort: bootstrap_register' messages
* :ghpull:`24051`: Backport PR #24037 on branch v3.6.x ([DOC]: make spanselector example codeblock continuous)
* :ghpull:`24037`: [DOC]: make spanselector example codeblock continuous
* :ghpull:`24045`: Fix _FigureManagerGTK.resize on GTK4
* :ghpull:`24043`: Backport PR #24041 on branch v3.6.x (DOC: Fix incorrect redirect)
* :ghpull:`24030`: Backport PR #24019 on branch v3.6.x (Don't require FigureCanvas on backend module more)
* :ghpull:`24040`: Backport PR #24018 on branch v3.6.x (When comparing eps images, run ghostscript with -dEPSCrop.)
* :ghpull:`24018`: When comparing eps images, run ghostscript with -dEPSCrop.
* :ghpull:`24033`: Backport PR #24032 on branch v3.6.x (Reword SpanSelector example.)
* :ghpull:`24029`: Backport PR #24026 on branch v3.6.x (Don't modify Axes property cycle in stackplot)
* :ghpull:`23994`: Backport PR #23964 on branch v3.6.x (Fix issue with empty line in ps backend)
* :ghpull:`24019`: Don't require FigureCanvas on backend module more
* :ghpull:`24026`: Don't modify Axes property cycle in stackplot
* :ghpull:`24027`: Backport PR #23904 on branch v3.6.x (added a reversing section to colormap reference)
* :ghpull:`24017`: Backport PR #24014 on branch v3.6.x (Bump pypa/cibuildwheel from 2.10.1 to 2.10.2)
* :ghpull:`24014`: Bump pypa/cibuildwheel from 2.10.1 to 2.10.2
* :ghpull:`24007`: Backport PR #24004 on branch v3.6.x (Increase consistency in tutorials and examples)
* :ghpull:`23964`: Fix issue with empty line in ps backend
* :ghpull:`23904`: added a reversing section to colormap reference
* :ghpull:`23990`: Backport PR #23978 on branch v3.6.x (DOC: Suppress IPython output in examples and tutorials where not needed)
* :ghpull:`23978`: DOC: Suppress IPython output in examples and tutorials where not needed
* :ghpull:`23916`: Backport PR #23912 on branch v3.6.x (FIX: only expect FigureCanvas on backend module if using new style)
* :ghpull:`23989`: Backport PR #23944 on branch v3.6.x (FIX: ValueError when hexbin is run with empty arrays and log scaling.)
* :ghpull:`23944`: FIX: ValueError when hexbin is run with empty arrays and log scaling.
* :ghpull:`23988`: Backport PR #23987 on branch v3.6.x (FIX: do not set constrained layout on false-y values)
* :ghpull:`23987`: FIX: do not set constrained layout on false-y values
* :ghpull:`23982`: Backport PR #23980 on branch v3.6.x (DOC: Move Quick Start Tutorial to first position)
* :ghpull:`23979`: Backport PR #23975 on branch v3.6.x (Reword docstring of reset_position.)
* :ghpull:`23975`: Reword docstring of reset_position.
* :ghpull:`23966`: Backport PR #23930 on branch v3.6.x (Fix edge color, links, wording; closes matplotlib/matplotlib#23895)
* :ghpull:`23971`: Backport PR #23906 on branch v3.6.x (Edit mplot3d examples for correctness and consistency)
* :ghpull:`23906`: Edit mplot3d examples for correctness and consistency
* :ghpull:`23963`: Backport PR #23957 on branch v3.6.x (Bump pypa/cibuildwheel from 2.9.0 to 2.10.1)
* :ghpull:`23930`: Fix edge color, links, wording; closes matplotlib/matplotlib#23895
* :ghpull:`23910`: FIX: do not append None to stream in ps
* :ghpull:`23957`: Bump pypa/cibuildwheel from 2.9.0 to 2.10.1
* :ghpull:`23960`: Backport PR #23947 on branch v3.6.x (Fix building on MINGW)
* :ghpull:`23942`: DOC: fix versions in v3.6.x doc switcher
* :ghpull:`23961`: Backport PR #23958 on branch v3.6.x (DOC: Remove Adding Animations section)
* :ghpull:`23958`: DOC: Remove Adding Animations section
* :ghpull:`23947`: Fix building on MINGW
* :ghpull:`23945`: Backport PR #23941 on branch v3.6.x (consistent notation for minor/patch branches)
* :ghpull:`23956`: Backport PR #23751 on branch v3.6.x (FIX: show bars when the first location is nan)
* :ghpull:`23751`: FIX: show bars when the first location is nan
* :ghpull:`23938`: Backport PR #23919 on branch v3.6.x (DOC: remove dead "Show Source" links)
* :ghpull:`23952`: Backport PR #23951 on branch v3.6.x (DOC: Make animation continuous)
* :ghpull:`23949`: DOC: Display "dev" instead of "devdocs" in the version switcher
* :ghpull:`23940`: Fix typos in github_stats.rst
* :ghpull:`23936`: Backport PR #23935 on branch v3.6.x (DOC: fix versions is doc switcher)
* :ghpull:`23933`: Backport PR #23932 on branch v3.6.x (DOC: Fix formatting in image tutorial)
* :ghpull:`23932`: DOC: Fix formatting in image tutorial
* :ghpull:`23926`: Backport PR #23925 on branch v3.6.x (FIX: use process_event in dpi changes on macosx backend)
* :ghpull:`23925`: FIX: use process_event in dpi changes on macosx backend
* :ghpull:`23912`: FIX: only expect FigureCanvas on backend module if using new style

Issues (22):

* :ghissue:`23981`: [ENH]: Default ``matplotlib.colormaps[None]`` to call ``matplotlib.colormaps[matplotlib.rcParams['image.cmap']]``?
* :ghissue:`24106`: [Bug]: fill_between gives IndexError with numpy 1.24.0.dev
* :ghissue:`24053`: Cartopy axes_grid_basic example broken by Matplotlib 3.6
* :ghissue:`23977`: [Bug]: Eqnarray in AnchoredText results in misplaced text (new in v3.6.0)
* :ghissue:`23973`: [Bug]: ValueError: Unable to determine Axes to steal space for Colorbar.
* :ghissue:`23456`: [Bug]: Horizontal colorbars drawn incorrectly with hatches
* :ghissue:`15922`: Pyplot gallery section is mostly OO examples
* :ghissue:`23700`: [Doc]: scatter points
* :ghissue:`23492`: [Bug]: svg backend does not use configured generic family lists
* :ghissue:`22528`: [Bug]: problem with font property in text elements of svg figures
* :ghissue:`23911`: [Bug]: 3.6.0 doesn't interact well with pycharm throwing "backend_interagg" exception
* :ghissue:`24024`: stackplot should not change Axes cycler
* :ghissue:`23954`: [Bug]: Text label with empty line causes a "TypeError: cannot unpack non-iterable NoneType object" in PostScript backend
* :ghissue:`23922`: [Bug]: Refactor of hexbin for 3.6.0 crashes with empty arrays and log scaling
* :ghissue:`23986`: [Bug]: Constrained layout UserWarning even when False
* :ghissue:`23895`: [Bug]: 3D surface is not plotted for the contour3d_3 example in the gallery
* :ghissue:`23955`: [Doc]: Adding animations to Youtube channel
* :ghissue:`23943`: [Bug]: Couldn't build matplotlib 3.6.0 with both Clang-15 and GCC-12
* :ghissue:`23687`: [Bug]: barplot does not show anything when x or bottom start and end with NaN
* :ghissue:`23876`: [Doc]: Missing source files
* :ghissue:`23909`: [Doc]: add animation examples to show animated subplots
* :ghissue:`23921`: [Bug]: resize_event deprecation warnings when creating figure on macOS with version 3.6.0
